/****************************************************************************
 * (c) 2019 softwareentwicklung-als-prozess.de
 * Funktionalitaet:
 * Ausgabe von Luftdruck, Luftfeuchte und Temperatur auf einem eInk Display
 ***************************************************************************/
// Includes -----------------------------------------------------------------
#include <SPI.h>
#include <epd1in54.h>
#include <epdpaint.h>
#include "eink_display.h"

// Definitionen
#define COLORED     0
#define UNCOLORED   1
  // Textfeld
#define EINK_TEXTLEN 12
#define BLANK  (char)32 // ASCII Leerzeichen
#define EMPTY  (char)48 // ASCII 0
#define ENDE   (char)0  // Stringende
#define PUNKT  (char)46 // ASCII .
#define DPUNKT (char)58 // ASCII :

// interne Prototypen
static void eInk_Cleartext(void);

// globale Variablen
unsigned char image[1024];
Paint paint(image, 0, 0);
Epd epd;
  // fuer Ausgabemaske
char  text[EINK_TEXTLEN];
float Temperatur = 0.0F;
float Feuchte    = 0.0F;
float Druck      = 0.0F;

// Funktionen
int eInk_Init(void)
{
  if (epd.Init(lut_full_update) != 0) 
  {
      return(EINK_ERROR);
  }
  epd.ClearFrameMemory(0xFF);
  epd.DisplayFrame();
  epd.ClearFrameMemory(0xFF);
  epd.DisplayFrame();
  // Bezieht sich auf die Textausgabe
  paint.SetRotate(ROTATE_270);
  // Textfenster
  paint.SetWidth(24);
  paint.SetHeight(200);

  // Logo ausgeben
  sprintf(text, "-- SEaP: --");  
  paint.Clear(UNCOLORED);
  paint.DrawStringAt(6, 0,text,&Font24, COLORED);
  epd.SetFrameMemory(paint.GetImage(), 98, 0, paint.GetWidth(), paint.GetHeight());
  eInk_Cleartext();
  
  epd.DisplayFrame();
  delay(1000);
  if (epd.Init(lut_partial_update) != 0) 
  {
      return(EINK_ERROR);
  }
  return(EINK_OK);  
}

void eInk_MesswerteAusgeben(void)
{
  int tmp  = (int)0;
  int frac = (int)0;

  paint.SetWidth(24);
  paint.SetHeight(200);
  paint.SetRotate(ROTATE_270);

  // Fenster loeschen
  paint.Clear(UNCOLORED);
  // Text im Fenster ausgeben: x = 0,y = 0 ist links unten im Fenster
  paint.DrawStringAt(6, 0, "Temperatur", &Font24, COLORED);
  // MemoryFrame bezieht sich auf das Display: x = 0,y = 0 ist links oben bei 0 Grad Drehung
  epd.SetFrameMemory(paint.GetImage(), 28, 0, paint.GetWidth(), paint.GetHeight());

  // Temperatur ausgeben
  tmp  = (int)Temperatur;                       // Vor komma
  frac = (int)(Temperatur * 10.0) - abs(tmp * 10); // eine Stelle nach Komma
  sprintf(text, "%+2d.%1d *C", tmp, frac);  
  paint.Clear(UNCOLORED);
  paint.DrawStringAt(6, 0,text,&Font24, COLORED);
  epd.SetFrameMemory(paint.GetImage(), 54, 0, paint.GetWidth(), paint.GetHeight());
  eInk_Cleartext();

  paint.Clear(UNCOLORED);
  paint.DrawStringAt(6, 0, "Luftdruck", &Font24, COLORED);
  epd.SetFrameMemory(paint.GetImage(), 78, 0, paint.GetWidth(), paint.GetHeight());

  // Luftdruck ausgeben
  tmp  = (int)Druck;                       // Vor komma
  frac = (int)(Druck * 10.0) - (tmp * 10); // eine Stelle nach Komma
  sprintf(text, "%4d.%1d hPa", tmp, frac);  
  paint.Clear(UNCOLORED);
  paint.DrawStringAt(6, 0,text,&Font24, COLORED);
  epd.SetFrameMemory(paint.GetImage(), 98, 0, paint.GetWidth(), paint.GetHeight());
  eInk_Cleartext();
  
  paint.Clear(UNCOLORED);
  paint.DrawStringAt(6, 0,"Luftfeuchte",&Font24, COLORED);
  epd.SetFrameMemory(paint.GetImage(), 126, 0, paint.GetWidth(), paint.GetHeight());

  // Luftfeuchte ausgeben
  tmp  = (int)Feuchte;                       // Vor komma
  frac = (int)(Feuchte * 10.0) - (tmp * 10); // eine Stelle nach Komma
  sprintf(text, "%2d.%1d Proz.", tmp, frac);  
  paint.Clear(UNCOLORED);
  paint.DrawStringAt(6, 0,text,&Font24, COLORED);
  epd.SetFrameMemory(paint.GetImage(), 150, 0, paint.GetWidth(), paint.GetHeight());
  eInk_Cleartext();

  epd.DisplayFrame();
}

// Textausgabefeld initialisieren
static void eInk_Cleartext(void)
{
  int i = 0;

  for(i = 0; i < (EINK_TEXTLEN - 1); i++)
  {
    text[i] = EMPTY;
  }
  text[EINK_TEXTLEN - 1] = ENDE;
}

void eInk_MesswerteSetzen(float temp, float feucht, float druck)
{
  Temperatur = temp;
  Feuchte    = feucht;
  Druck      = druck;
}
